from django.db import models
from edc_model.models import BaseUuidModel, HistoricalRecords
from edc_model_fields.fields import OtherCharField
from edc_sites.managers import CurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_utils import formatted_date

from intecomm_facility.models import HealthFacility
from intecomm_lists.models import HealthTalkTypes


class Manager(models.Manager):
    use_in_migrations = True

    def get_by_natural_key(self, health_facility, report_date):
        return self.get(health_facility=health_facility, report_date=report_date)


class HealthTalkLog(SiteModelMixin, BaseUuidModel):
    # TODO: Remove field after migrations are squashed/reset
    old_health_facility = models.CharField(max_length=100, null=True)

    health_facility = models.ForeignKey(
        HealthFacility,
        verbose_name="Health facility",
        on_delete=models.PROTECT,
        null=True,
    )

    health_talk_type = models.ForeignKey(
        HealthTalkTypes, verbose_name="Type of talk", on_delete=models.PROTECT
    )

    health_talk_type_other = OtherCharField()

    report_date = models.DateField()

    number_attended = models.IntegerField(
        verbose_name="Approximate number attended",
    )

    notes = models.TextField(null=True, blank=True)

    objects = Manager()
    on_site = CurrentSiteManager()
    history = HistoricalRecords()

    def __str__(self):
        dt = formatted_date(self.report_date)
        return f"{self.health_facility} on {dt}"

    def natural_key(self):
        return (
            self.health_facility,
            self.report_date,
        )

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Health talk log"
        verbose_name_plural = "Health talk logs"
        unique_together = ("health_facility", "report_date")



from .assets_admin import HealthEconomicsAssetsAdmin
from .household_head_admin import HealthEconomicsHouseholdHeadAdmin
from .income_admin import HealthEconomicsIncomeAdmin
from .patient_admin import HealthEconomicsPatientAdmin
from .property_admin import HealthEconomicsPropertyAdmin



from dateutil.relativedelta import relativedelta
from edc_constants.constants import EQ, NO, NOT_APPLICABLE, YES
from edc_dx_review.constants import THIS_CLINIC
from edc_utils import get_utcnow
from faker import Faker
from model_bakery.recipe import Recipe

from .models import (
    ClinicalReview,
    ClinicalReviewBaseline,
    DmInitialReview,
    DmReview,
    HealthEconomicsHouseholdHead,
    HivInitialReview,
    HivReview,
    HtnInitialReview,
    HtnReview,
)

fake = Faker()

clinicalreviewbaseline = Recipe(
    ClinicalReviewBaseline,
    report_datetime=get_utcnow(),
    hiv_dx=NO,
    hiv_dx_at_screening=NOT_APPLICABLE,
    dm_dx=NO,
    dm_dx_at_screening=NOT_APPLICABLE,
    htn_dx=NO,
    htn_dx_at_screening=NOT_APPLICABLE,
)

clinicalreview = Recipe(
    ClinicalReview,
    report_datetime=get_utcnow(),
    hiv_test=NO,
    hiv_test_date=None,
    htn_test=NO,
    htn_test_date=None,
    dm_test=NO,
    dm_test_date=None,
)


hivinitialreview = Recipe(
    HivInitialReview,
    report_datetime=get_utcnow(),
    receives_care=YES,
    clinic=THIS_CLINIC,
    has_vl=YES,
    vl=50,
    vl_quantifier=EQ,
    drawn_date=(get_utcnow() - relativedelta(months=5)).date(),
    has_cd4=NO,
)

dminitialreview = Recipe(
    DmInitialReview,
    report_datetime=get_utcnow(),
)

htninitialreview = Recipe(
    HtnInitialReview, report_datetime=get_utcnow(), rx_init_date_is_estimated=NO
)


hivreview = Recipe(
    HivReview,
    report_datetime=get_utcnow(),
)

dmreview = Recipe(
    DmReview,
    report_datetime=get_utcnow(),
)

htnreview = Recipe(
    HtnReview,
    report_datetime=get_utcnow(),
)

healtheconomicshouseholdhead = Recipe(
    HealthEconomicsHouseholdHead,
    report_datetime=get_utcnow(),
)



from edc_constants.constants import NO
from edc_utils import get_utcnow
from faker import Faker
from intecomm_form_validators import RECRUITING
from model_bakery.recipe import Recipe

from .models import PatientGroup

fake = Faker()

name = fake.name()
names = name.split(" ")
firstname = names[0].upper()
lastname = names[-1].upper()
initials = f"{firstname[0]}{lastname[0]}".upper()


patientgroup = Recipe(
    PatientGroup,
    report_datetime=get_utcnow(),
    status=RECRUITING,
    randomize_now=NO,
)



# Generated by Django 4.2.7 on 2023-12-05 20:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0130_remove_bloodresultsfbc_intecomm_su_subject_1b56bc_idx_and_more",
        ),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="drugrefillhtn",
            name="intecomm_su_subject_33642b_idx",
        ),
        migrations.RemoveIndex(
            model_name="eq5d3l",
            name="intecomm_su_subject_26cbd6_idx",
        ),
        migrations.RemoveIndex(
            model_name="familyhistory",
            name="intecomm_su_subject_70b52d_idx",
        ),
        migrations.RemoveIndex(
            model_name="glucose",
            name="intecomm_su_subject_d7452b_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomics",
            name="intecomm_su_subject_0fa533_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicsassets",
            name="intecomm_su_subject_db2b9f_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicshouseholdhead",
            name="intecomm_su_subject_70ec19_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicsincome",
            name="intecomm_su_subject_cd28df_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicspatient",
            name="intecomm_su_subject_9f534c_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicsproperty",
            name="intecomm_su_subject_46df27_idx",
        ),
        migrations.RemoveIndex(
            model_name="hivinitialreview",
            name="intecomm_su_subject_105e1e_idx",
        ),
        migrations.RemoveIndex(
            model_name="hivmedicationadherence",
            name="intecomm_su_subject_0c187e_idx",
        ),
        migrations.RemoveIndex(
            model_name="hivreview",
            name="intecomm_su_subject_330463_idx",
        ),
        migrations.RemoveIndex(
            model_name="htninitialreview",
            name="intecomm_su_subject_26645e_idx",
        ),
        migrations.RemoveIndex(
            model_name="htnmedicationadherence",
            name="intecomm_su_subject_3c2519_idx",
        ),
        migrations.RemoveIndex(
            model_name="htnreview",
            name="intecomm_su_subject_68a66a_idx",
        ),
        migrations.RemoveIndex(
            model_name="icecapa",
            name="intecomm_su_subject_9061b4_idx",
        ),
        migrations.RemoveIndex(
            model_name="locationupdate",
            name="intecomm_su_subject_2ca9cc_idx",
        ),
        migrations.RemoveIndex(
            model_name="malariatest",
            name="intecomm_su_subject_dd6f65_idx",
        ),
        migrations.RemoveIndex(
            model_name="medications",
            name="intecomm_su_subject_f7efc4_idx",
        ),
        migrations.RemoveIndex(
            model_name="nextappointment",
            name="intecomm_su_subject_877d51_idx",
        ),
        migrations.RemoveIndex(
            model_name="otherbaselinedata",
            name="intecomm_su_subject_3430b9_idx",
        ),
        migrations.RemoveIndex(
            model_name="socialharms",
            name="intecomm_su_subject_99ad70_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectrequisition",
            name="intecomm_su_subject_eb844f_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissed",
            name="intecomm_su_subject_8770a0_idx",
        ),
        migrations.RemoveIndex(
            model_name="urinedipsticktest",
            name="intecomm_su_subject_c1ab9f_idx",
        ),
        migrations.RemoveIndex(
            model_name="urinepregnancy",
            name="intecomm_su_subject_e044a5_idx",
        ),
        migrations.RemoveIndex(
            model_name="viralloadresult",
            name="intecomm_su_subject_91aacf_idx",
        ),
        migrations.RemoveIndex(
            model_name="vitals",
            name="intecomm_su_subject_204579_idx",
        ),
    ]



from __future__ import annotations

from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
from django.db.models import Q
from django.urls import reverse
from edc_dashboard.view_mixins import EdcViewMixin
from edc_listboard.view_mixins import ListboardFilterViewMixin, SearchFormViewMixin
from edc_listboard.views import ListboardView as BaseListboardView
from edc_navbar import NavbarViewMixin
from edc_sites import site_sites

from intecomm_group.models import PatientGroup
from intecomm_group.utils import get_assignment_for_patient_group


class SubjectListboardView(
    EdcViewMixin,
    NavbarViewMixin,
    ListboardFilterViewMixin,
    SearchFormViewMixin,
    BaseListboardView,
):
    listboard_template = "subject_listboard_template"
    listboard_url = "subject_listboard_url"
    listboard_panel_style = "success"
    listboard_panel_title = "Subjects in randomized groups"
    listboard_fa_icon = "far fa-user-circle"
    listboard_model = "intecomm_screening.patientlog"
    listboard_view_permission_codename = "edc_subject_dashboard.view_subject_listboard"
    navbar_selected_item = "subjects"
    search_form_url = "subject_listboard_url"
    ordering: str = "-subject_identifier"
    show_change_form_button = False
    paginate_by = 20
    search_fields = [
        "user_created",
        "user_modified",
        "screening_identifier",
        "subject_identifier",
        "group_identifier",
        "patient_log_identifier",
        "filing_identifier",
        "initials__exact",
        "hospital_identifier__exact",
        "last_4_hospital_identifier",
        "contact_number__exact",
        "alt_contact_number__exact",
        "last_4_contact_number",
        "legal_name__exact",
    ]

    def get_context_data(self, **kwargs) -> dict:
        kwargs.update(
            patient_group_url=self.get_patient_group_url(**kwargs),
            patient_group_appointment_url=self.get_patient_group_appointment_url(**kwargs),
            patient_group_meeting_url=self.get_patient_group_meeting_url(**kwargs),
            patient_group=self.patient_group,
            # arm=self.arm,
            site=getattr(self.request, "site", None),
            country=site_sites.get_current_country(self.request),
        )
        return super().get_context_data(**kwargs)

    def get_queryset_filter_options(self, request, *args, **kwargs) -> tuple[Q, dict]:
        q_object, options = super().get_queryset_filter_options(request, *args, **kwargs)
        options.update(subject_identifier__startswith="107-", group_identifier__isnull=False)
        if kwargs.get("subject_identifier"):
            options.update({"subject_identifier": kwargs.get("subject_identifier")})
        return q_object, options

    @property
    def patient_group(self) -> PatientGroup:
        try:
            obj = PatientGroup.objects.get(
                Q(group_identifier__exact=self.raw_search_term)
                | Q(name__exact=self.raw_search_term)
            )
        except (ObjectDoesNotExist, MultipleObjectsReturned):
            obj = None
        return obj

    def get_patient_group_url(self, **kwargs) -> str:
        url = reverse("intecomm_group_admin:intecomm_group_patientgroup_changelist")
        return f"{url}?q={self.raw_search_term}"

    def get_patient_group_appointment_url(self, **kwargs) -> str:
        url = reverse("intecomm_group_admin:intecomm_group_patientgroupappointment_changelist")
        return f"{url}?q={self.raw_search_term}"

    def get_patient_group_meeting_url(self, **kwargs) -> str:
        url = reverse("intecomm_group_admin:intecomm_group_patientgroupmeeting_changelist")
        return f"{url}?q={self.raw_search_term}"

    @property
    def arm(self) -> str | None:
        if self.patient_group:
            return get_assignment_for_patient_group(self.patient_group.group_identifier)
        return None



# Generated by Django 4.1.2 on 2023-01-27 01:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0010_remove_historicalvitals_weight_is_estmated_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="complications",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="complications",
        ),
        migrations.AlterField(
            model_name="historicalvitals",
            name="severe_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="severe_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2023-01-27 02:45

from django.db import migrations
import edc_vitals.models.fields.heart_rate
import edc_vitals.models.fields.temperature


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0011_remove_clinicalreviewbaseline_complications_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalvitals",
            name="heart_rate",
            field=edc_vitals.models.fields.heart_rate.HeartRateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalvitals",
            name="temperature",
            field=edc_vitals.models.fields.temperature.TemperatureField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="heart_rate",
            field=edc_vitals.models.fields.heart_rate.HeartRateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="temperature",
            field=edc_vitals.models.fields.temperature.TemperatureField(blank=True, null=True),
        ),
    ]



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from intecomm_form_validators.subject import ClinicalReviewBaselineFormValidator

from ..models import ClinicalReviewBaseline


class ClinicalReviewBaselineForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = ClinicalReviewBaselineFormValidator

    class Meta:
        model = ClinicalReviewBaseline
        fields = "__all__"



from django import forms
from edc_form_validators import FormValidator
from edc_model_fields.widgets import SliderWidget

from ..models import Eq5d3l
from .mixins import CrfModelFormMixin


class Eq5d3lFormValidator(FormValidator):
    pass


class Eq5d3lForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = Eq5d3lFormValidator

    health_today_score_slider = forms.CharField(
        label="Visual Score", widget=SliderWidget(attrs={"min": 0, "max": 100})
    )

    class Meta:
        model = Eq5d3l
        fields = "__all__"



from typing import Tuple

from django.apps import apps as django_apps
from django.conf import settings
from django.contrib import admin
from django.template.loader import render_to_string
from django.urls import reverse
from django.utils.html import format_html
from edc_model_admin.dashboard import ModelAdminDashboardMixin
from edc_model_admin.mixins import ModelAdminRedirectAllToChangelistMixin
from edc_registration.models import RegisteredSubject
from edc_sites.admin import SiteModelAdminMixin
from edc_utils import convert_php_dateformat
from edc_utils.date import to_local

from intecomm_screening.admin.list_filters import LastApptListFilter, NextApptListFilter
from intecomm_screening.admin.modeladmin_mixins import BaseModelAdminMixin

from ..admin_site import intecomm_group_admin
from ..forms import PatientFollowupCallForm
from ..models import PatientFollowupCall
from .list_filters import PatientGroupLastCallListFilter


@admin.register(PatientFollowupCall, site=intecomm_group_admin)
class PatientFollowupCallAdmin(
    ModelAdminRedirectAllToChangelistMixin,
    ModelAdminDashboardMixin,
    SiteModelAdminMixin,
    BaseModelAdminMixin,
):
    form = PatientFollowupCallForm
    show_object_tools = False
    change_list_template: str = "intecomm_group/admin/patientfollowupcall_change_list.html"
    ordering = ["-report_datetime", "patient_log__subject_identifier"]

    changelist_url = "intecomm_group_admin:intecomm_group_patientfollowupcall_changelist"
    change_search_field_name = "patient_log__subject_identifier"
    add_search_field_name = "patient_log"

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "patient_log",
                    "report_datetime",
                )
            },
        ),
        (
            "Contact numbers",
            {
                "fields": (
                    "contact_number",
                    "alt_contact_number",
                )
            },
        ),
        (
            "Details of call",
            {
                "fields": (
                    "answered",
                    "respondent",
                    "call_again",
                    "survival_status",
                    "catchment_area",
                    "last_appt_date",
                    "next_appt_date",
                    "comment",
                )
            },
        ),
    )

    list_display = (
        "subject_identifier",
        "dashboard",
        "subject_locator",
        "call_summary",
        "last_appt",
        "next_appt",
    )

    list_filter = (
        PatientGroupLastCallListFilter,
        LastApptListFilter,
        NextApptListFilter,
        "answered",
        "call_again",
        "respondent",
        "survival_status",
        "catchment_area",
    )

    radio_fields = {
        "answered": admin.VERTICAL,
        "respondent": admin.VERTICAL,
        "survival_status": admin.VERTICAL,
        "catchment_area": admin.VERTICAL,
        "call_again": admin.VERTICAL,
    }

    search_fields = (
        "patient_log__subject_identifier",
        "patient_log__id",
        "patient_log__legal_name__exact",
        "patient_log__familiar_name__exact",
    )

    @admin.display(description="Patient", ordering="patient_log")
    def patient_log_link(self, obj=None):
        url = reverse("intecomm_screening_admin:intecomm_screening_patientlog_changelist")
        url = f"{url}?q={obj.patient_log.id}"
        return format_html(f'<A href="{url}">{obj.patient_log}</a>')

    @property
    def patient_log_model_cls(self):
        return django_apps.get_model("intecomm_screening.patientlog")

    @admin.display(description="Locator", ordering="subject_identifier")
    def subject_locator(self, obj=None):
        url = reverse("intecomm_prn_admin:intecomm_prn_subjectlocator_changelist")
        context = dict(url=f"{url}?q={obj.patient_log.subject_identifier}")
        return render_to_string(
            "intecomm_group/patient_followup_call_locator.html", context=context
        )

    @admin.display(description="Summary", ordering="report_datetime")
    def call_summary(self, obj=None):
        date_format = convert_php_dateformat(settings.SHORT_DATE_FORMAT)
        context = dict(
            last_call=to_local(obj.report_datetime).date().strftime(date_format),
            answered=obj.answered,
            survival_status=obj.survival_status,
            catchment_area=obj.catchment_area,
            call_again=obj.call_again,
            respondent=obj.get_respondent_display(),
        )
        return render_to_string(
            "intecomm_group/patient_followup_call_summary.html", context=context
        )

    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        if db_field.name == "patient_log":
            if request.GET.get("patient_log"):
                kwargs["queryset"] = self.patient_log_model_cls.objects.filter(
                    id__exact=request.GET.get("patient_log", 0)
                )
            else:
                kwargs["queryset"] = self.patient_log_model_cls.objects.none()
        return super().formfield_for_foreignkey(db_field, request, **kwargs)

    def get_readonly_fields(self, request, obj=None) -> Tuple[str, ...]:
        readonly = super().get_readonly_fields(request, obj=obj)
        if obj and "patient_log" not in readonly:
            readonly = readonly + ("patient_log",)
        return readonly

    @admin.display(
        description="Subject identifier", ordering="patient_log__subject_identifier"
    )
    def subject_identifier(self, obj):
        return obj.patient_log.subject_identifier

    def get_subject_dashboard_url_kwargs(self, obj) -> dict:
        return dict(subject_identifier=obj.patient_log.subject_identifier)

    def get_registered_subject(self, obj) -> RegisteredSubject:
        return RegisteredSubject.objects.get(
            subject_identifier=obj.patient_log.subject_identifier
        )

    @admin.display(description="Alive", ordering="survival_status")
    def alive(self, obj):
        return obj.survival_status

    @admin.display(description="Catchment", ordering="catchment_area")
    def in_catchment_area(self, obj):
        return obj.catchment_area

    @admin.display(description="Call again?", ordering="call_again")
    def may_call_again(self, obj):
        return obj.call_again

    @admin.display(description="Last appt", ordering="last_appt_date")
    def last_appt(self, obj):
        if obj.last_appt_date:
            date_format = convert_php_dateformat(settings.SHORT_DATE_FORMAT)
            return format_html(
                f'<span style="white-space:nowrap;">'
                f"{obj.last_appt_date.strftime(date_format)}</span>"
            )
        return None

    @admin.display(description="Next appt", ordering="next_appt_date")
    def next_appt(self, obj):
        if obj.next_appt_date:
            date_format = convert_php_dateformat(settings.SHORT_DATE_FORMAT)
            return format_html(
                f'<span style="white-space:nowrap;">'
                f"{obj.next_appt_date.strftime(date_format)}</span>"
            )
        return None



from django.db import models
from edc_constants.choices import YES_NO
from edc_constants.constants import NO, NOT_APPLICABLE
from edc_metadata.model_mixins.creates import CreatesMetadataModelMixin
from edc_model.models import BaseUuidModel, HistoricalRecords
from edc_offstudy.model_mixins import OffstudyNonCrfModelMixin
from edc_sites.managers import CurrentSiteManager as BaseCurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_visit_tracking.managers import VisitModelManager
from edc_visit_tracking.model_mixins import VisitModelMixin

from ..choices import INFO_SOURCE, VISIT_REASON, VISIT_UNSCHEDULED_REASON


class CurrentSiteManager(VisitModelManager, BaseCurrentSiteManager):
    pass


class SubjectVisit(
    VisitModelMixin,
    CreatesMetadataModelMixin,
    SiteModelMixin,
    OffstudyNonCrfModelMixin,
    BaseUuidModel,
):
    """A model completed by the user that captures the covering
    information for the data collected for this timepoint/appointment,
    e.g.report_datetime.
    """

    reason = models.CharField(
        verbose_name="What is the reason for this visit report?",
        max_length=25,
        choices=VISIT_REASON,
        help_text="If 'missed', fill in the separate missed visit report",
    )

    reason_unscheduled = models.CharField(
        verbose_name="If 'unscheduled', provide reason for the unscheduled visit",
        max_length=25,
        choices=VISIT_UNSCHEDULED_REASON,
        default=NOT_APPLICABLE,
    )

    unschedule_self_referral = models.CharField(
        verbose_name="If 'unschedule', is this a self-referral?",
        max_length=25,
        choices=YES_NO,
        default=NO,
    )

    unschedule_detail = models.TextField(
        verbose_name="If 'unschedule', please provide further details, if any",
        null=True,
        blank=True,
    )

    info_source = models.CharField(
        verbose_name="What is the main source of this information?",
        max_length=25,
        choices=INFO_SOURCE,
    )

    objects = VisitModelManager()

    on_site = CurrentSiteManager()

    history = HistoricalRecords()

    class Meta(VisitModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Subject visit"
        verbose_name_plural = "Subject visits"
        indexes = VisitModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from django.db import models
from edc_model.models import BaseUuidModel
from edc_rx.model_mixins import DrugSupplyModelMixin

from intecomm_lists.models import ArvDrugs

from .drug_refill_hiv import DrugRefillHiv


class DrugSupplyHiv(DrugSupplyModelMixin, BaseUuidModel):
    drug_refill = models.ForeignKey(DrugRefillHiv, on_delete=models.PROTECT)

    drug = models.ForeignKey(ArvDrugs, on_delete=models.PROTECT)

    def __str__(self):
        return self.drug_refill.rx.display_name

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Drug Supply: HIV"
        verbose_name_plural = "Drug Supply: HIV"
